@@ -1035,6 +1035,15 @@ void MainApplication::loadSettings()
 #if QTWEBENGINECORE_VERSION >= QT_VERSION_CHECK(6, 7, 0)
     webSettings->setAttribute(QWebEngineSettings::ForceDarkMode, settings.value(QSL("forceDarkMode"), false).toBool());
 #endif
+#if QTWEBENGINECORE_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+    const bool allowImageAnimation = settings.value(QSL("allowImageAnimation"), true).toBool();
+    if (allowImageAnimation) {
+        webSettings->setImageAnimationPolicy(QWebEngineSettings::ImageAnimationPolicy::Allow);
+    }
+    else {
+        webSettings->setImageAnimationPolicy(QWebEngineSettings::ImageAnimationPolicy::Disallow);
+    }
+#endif
 
     webSettings->setDefaultTextEncoding(settings.value(QSL("DefaultEncoding"), webSettings->defaultTextEncoding()).toString());
 
