@@ -42,7 +42,7 @@ void AutoFillWidget::setUsernames(const QStringList &usernames)
             continue;
         }
 
-        QPushButton* button = new QPushButton(this);
+        auto* button = new QPushButton(this);
         button->setIcon(QIcon(QSL(":icons/other/login.png")));
         button->setStyleSheet(QSL("text-align:left;font-weight:bold;"));
         button->setText(username);
