@@ -34,10 +34,13 @@ class FALKON_EXPORT SiteInfoWidget : public LocationBarPopup
 {
     Q_OBJECT
 public:
-    explicit SiteInfoWidget(BrowserWindow* window, QWidget* parent = 0);
+    explicit SiteInfoWidget(BrowserWindow* window, QWidget* parent = nullptr);
     ~SiteInfoWidget();
 
 private:
+    void updateProtocolHandler();
+    void protocolHandlerButtonClicked();
+
     Ui::SiteInfoWidget* ui;
     BrowserWindow* m_window;
 };
