@@ -23,7 +23,7 @@
 
 class KWalletPasswordBackend;
 class KIOSchemeHandler;
-class KUiServerJobTracker;
+class KUiServerV2JobTracker;
 
 class KDEFrameworksIntegrationPlugin : public QObject, public PluginInterface
 {
@@ -43,5 +43,5 @@ private:
     KWalletPasswordBackend *m_backend = nullptr;
     QVector<KIOSchemeHandler*> m_kioSchemeHandlers;
     Purpose::Menu *m_sharePageMenu = nullptr;
-    KUiServerJobTracker *m_jobTracker = nullptr;
+    KUiServerV2JobTracker *m_jobTracker = nullptr;
 };
