@@ -22,19 +22,13 @@
 #include "browserwindow.h"
 #include "../config.h"
 #include "mainapplication.h"
-#include "desktopfile.h"
 
 StatusBarIconsPlugin::StatusBarIconsPlugin()
     : QObject()
-    , m_manager(0)
+    , m_manager(nullptr)
 {
 }
 
-DesktopFile StatusBarIconsPlugin::metaData() const
-{
-    return DesktopFile(QSL(":sbi/metadata.desktop"));
-}
-
 void StatusBarIconsPlugin::init(InitState state, const QString &settingsPath)
 {
     m_manager = new SBI_IconsManager(settingsPath);
@@ -44,7 +38,8 @@ void StatusBarIconsPlugin::init(InitState state, const QString &settingsPath)
 
     // Make sure icons are added also to already created windows
     if (state == LateInitState) {
-        foreach (BrowserWindow* window, mApp->windows()) {
+        const auto windows = mApp->windows();
+        for (BrowserWindow* window : windows) {
             m_manager->mainWindowCreated(window);
         }
     }
@@ -54,7 +49,8 @@ void StatusBarIconsPlugin::unload()
 {
     // Make sure icons are properly removed when unloading plugin (but not when closing app)
     if (!mApp->isClosing()) {
-        foreach (BrowserWindow* window, mApp->windows()) {
+        const auto windows = mApp->windows();
+        for (BrowserWindow* window : windows) {
             m_manager->mainWindowDeleted(window);
         }
 
@@ -65,11 +61,11 @@ void StatusBarIconsPlugin::unload()
 bool StatusBarIconsPlugin::testPlugin()
 {
     // Require the version that the plugin was built with
-    return (Qz::VERSION == QLatin1String(FALKON_VERSION));
+    return (QString::fromLatin1(Qz::VERSION) == QLatin1String(FALKON_VERSION));
 }
 
 void StatusBarIconsPlugin::showSettings(QWidget* parent)
 {
-    SBI_SettingsDialog* dialog = new SBI_SettingsDialog(m_manager, parent);
+    auto* dialog = new SBI_SettingsDialog(m_manager, parent);
     dialog->open();
 }
